Calculation of arithmetic-average Asian call price
using control variate Monte Carlo valuation
Usage
arithavgpricecv(s, k, v, r, tt, d, m, numsim)
Value
Vector of the price of an arithmetic-average Asian call,
computed using a control variate Monte Carlo calculation, along
with the regression beta used for adjusting the price.
Arguments
s
Price of underlying asset
k
Strike price of the option. In the case of average strike
options, k/s is the multiplier for the average
v
Volatility of the underlygin asset price, defined as the
annualized standard deviation of the continuously-compounded
return